summaryrefslogtreecommitdiffstats
path: root/Lib/test/test_script_helper.py
diff options
context:
space:
mode:
Diffstat (limited to 'Lib/test/test_script_helper.py')
-rw-r--r--Lib/test/test_script_helper.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/Lib/test/test_script_helper.py b/Lib/test/test_script_helper.py
index 8694530..a7680f8 100644
--- a/Lib/test/test_script_helper.py
+++ b/Lib/test/test_script_helper.py
@@ -1,8 +1,8 @@
"""Unittests for test.script_helper. Who tests the test helper?"""
import subprocess
import sys
-from test import script_helper
+from test.support import script_helper
import unittest
from unittest import mock
@@ -1,8 +1,8 @@
-"""Unittests for test.script_helper. Who tests the test helper?"""
+"""Unittests for test.support.script_helper. Who tests the test helper?"""
import subprocess
import sys